@@ -1,5 +1,5 @@
 from typing import Optional, List, Union
-from hein_robots.robotics import Location, Twist, Wrench, Cartesian, Orientation, Units
+from hein_robots.robotics import Location, Twist, Wrench, Cartesian, Orientation, Units, Frame
 from hein_robots.base.actuators import Actuator
 from hein_robots.base.grippers import Gripper
 
@@ -136,7 +136,7 @@ class RobotArm:
 
     def move(self, x: Optional[float] = None, y: Optional[float] = None, z: Optional[float] = None,
              rx: Optional[float] = None, ry: Optional[float] = None, rz: Optional[float] = None,
-             velocity: Optional[float] = None, acceleration: Optional[float] = None,
+             frame: Optional[Frame] = None, velocity: Optional[float] = None, acceleration: Optional[float] = None,
              relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
         if not relative:
             location = Location(
@@ -150,21 +150,43 @@ class RobotArm:
         else:
             location = Location(x or 0, y or 0, z or 0, rx or 0, ry or 0, rz or 0)
 
-        self.move_to_location(location, velocity=velocity, acceleration=acceleration, relative=relative, wait=wait,
+        self.move_to_location(location, frame=frame, velocity=velocity, acceleration=acceleration, relative=relative, wait=wait,
                               timeout=timeout)
 
-    def move_to_location(self, location: Location,
+    def move_tool(self, x: Optional[float] = None, y: Optional[float] = None, z: Optional[float] = None,
+             rx: Optional[float] = None, ry: Optional[float] = None, rz: Optional[float] = None,
+             velocity: Optional[float] = None, acceleration: Optional[float] = None,
+             wait: bool = True, timeout: Optional[float] = None):
+        location = Location(x or 0, y or 0, z or 0, rx or 0, ry or 0, rz or 0)
+        self.move_to_location(location, frame=self.location, velocity=velocity, acceleration=acceleration, relative=False, wait=wait,
+                              timeout=timeout)
+
+    def move_to_location(self, location: Location, frame: Optional[Frame] = None,
                          velocity: Optional[float] = None, acceleration: Optional[float] = None,
                          relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
         pass
 
-    def move_to_locations(self, *locations: Location,
+    def move_tool_to_location(self, location: Location,
+                         velocity: Optional[float] = None, acceleration: Optional[float] = None,
+                         relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
+        self.move_to_location(location, frame=self.location,
+                              velocity=velocity, acceleration=acceleration,
+                              relative=relative, wait=wait, timeout=timeout)
+
+    def move_to_locations(self, *locations: Location, frame: Optional[Frame] = None,
                           velocity: Optional[float] = None, acceleration: Optional[float] = None,
                           relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
         for location in locations:
-            self.move_to_location(location, velocity=velocity, acceleration=acceleration,
+            self.move_to_location(location, frame=frame,
+                                  velocity=velocity, acceleration=acceleration,
                                   relative=relative, wait=wait, timeout=timeout)
 
+    def move_tool_to_locations(self, *locations: Location,
+                          velocity: Optional[float] = None, acceleration: Optional[float] = None,
+                          relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
+        self.move_to_locations(*locations, velocity=velocity, acceleration=acceleration,
+                               relative=relative, wait=wait, timeout=timeout)
+
     def move_joints(self, joint_positions: List[float],
                     velocity: Optional[float] = None, acceleration: Optional[float] = None,
                     relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
